# Comparison Space Generation

The comparison space is a storage facility which contains entity references
arranged in a way that makes them ready for comparison operations.
In entity resolution, comparison operations may be performed in terms of
similarity (matching) or metric distance (clustering).

In the basic case, comparison operations are binary and so the binary comparison
space is not much more than a enumeration of pairs of entity references.

# Development

Run the following command to ensure you have all the dependencies ready and that
the project is set up correctly.

```shell
$ make test
```

Afterward, follow the guidelines to contribute code to this repository. 